@@ -1,6 +1,6 @@
 /*********************************************************************
 This file is part of the argtable2 library.
-Copyright (C) 1998-2001,2003-2007 Stewart Heitmann
+Copyright (C) 1998-2001,2003-2008 Stewart Heitmann
 sheitmann@users.sourceforge.net
 
 The argtable2 library is free software; you can redistribute it and/or
@@ -177,6 +177,8 @@ struct arg_file* arg_filen(const char* shortopts,
     result = (struct arg_file*)malloc(nbytes);
     if (result)
         {
+        int i;
+
         /* init the arg_hdr struct */
         result->hdr.flag      = ARG_HASVALUE;
         result->hdr.shortopts = shortopts;
@@ -196,6 +198,14 @@ struct arg_file* arg_filen(const char* shortopts,
         result->basename  = result->filename + maxcount;
         result->extension = result->basename + maxcount;
         result->count = 0;
+
+        /* foolproof the string pointers by initialising them with empty strings */
+        for (i=0; i<maxcount; i++)
+            {
+            result->filename[i] = "";
+            result->basename[i] = "";
+            result->extension[i] = "";
+            }
         }
     /*printf("arg_filen() returns %p\n",result);*/
     return result;
