@@ -1,6 +1,6 @@
 /*********************************************************************
 This file is part of the argtable2 library.
-Copyright (C) 1998-2001,2003-2007 Stewart Heitmann
+Copyright (C) 1998-2001,2003-2008 Stewart Heitmann
 sheitmann@users.sourceforge.net
 
 The argtable2 library is free software; you can redistribute it and/or
@@ -188,7 +188,7 @@ struct arg_rex* arg_rexn(const char* shortopts,
     result = (struct arg_rex*)malloc(nbytes);
     if (result)
         {
-        int errorcode;
+        int errorcode, i;
 
         /* init the arg_hdr struct */
         result->hdr.flag      = ARG_HASVALUE;
@@ -214,6 +214,10 @@ struct arg_rex* arg_rexn(const char* shortopts,
         result->sval  = (const char**)(priv+1);
         result->count = 0;
 
+        /* foolproof the string pointers by initialising them to reference empty strings */
+        for (i=0; i<maxcount; i++)
+            { result->sval[i] = ""; }
+
         /* here we construct and destroy a regex representation of the regular expression
            for no other reason than to force any regex errors to be trapped now rather
            than later. If we dont, then errors may go undetected until an argument is
