@@ -1,6 +1,6 @@
 /*********************************************************************
 This file is part of the argtable2 library.
-Copyright (C) 1998-2001,2003-2007 Stewart Heitmann
+Copyright (C) 1998-2001,2003-2008 Stewart Heitmann
 sheitmann@users.sourceforge.net
 
 The argtable2 library is free software; you can redistribute it and/or
@@ -132,6 +132,8 @@ struct arg_str* arg_strn(const char* shortopts,
     result = (struct arg_str*)malloc(nbytes);
     if (result)
         {
+        int i;
+
         /* init the arg_hdr struct */
         result->hdr.flag      = ARG_HASVALUE;
         result->hdr.shortopts = shortopts;
@@ -149,6 +151,10 @@ struct arg_str* arg_strn(const char* shortopts,
         /* store the sval[maxcount] array immediately after the arg_str struct */
         result->sval  = (const char**)(result+1);
         result->count = 0;
+
+        /* foolproof the string pointers by initialising them to reference empty strings */
+        for (i=0; i<maxcount; i++)
+            { result->sval[i] = ""; }
         }
     /*printf("arg_strn() returns %p\n",result);*/
     return result;
