@@ -1,6 +1,6 @@
 /*********************************************************************
 This file is part of the argtable2 library.
-Copyright (C) 1998-2001,2003-2007 Stewart Heitmann
+Copyright (C) 1998-2001,2003-2008 Stewart Heitmann
 sheitmann@users.sourceforge.net
 
 The argtable2 library is free software; you can redistribute it and/or
@@ -301,10 +301,11 @@ void arg_parse_tagged(int argc, char **argv, struct arg_hdr **table, struct arg_
                 /*printf("long option detected from argtable[%d]\n", tabindex);*/
                 if (optarg && optarg[0]==0 && (table[tabindex]->flag & ARG_HASVALUE))
                     {
-                    printf(": long option %s requires an argument\n",argv[optind-1]);
+                    /* printf(": long option %s requires an argument\n",argv[optind-1]); */
                     arg_register_error(endtable,endtable,ARG_EMISSARG,argv[optind-1]);
+                    /* continue to scan the (empty) argument value to enforce argument count checking */
                     }
-                else if (table[tabindex]->scanfn)
+                if (table[tabindex]->scanfn)
                     {
                     int errorcode = table[tabindex]->scanfn(parent,optarg);
                     if (errorcode!=0)
@@ -315,7 +316,7 @@ void arg_parse_tagged(int argc, char **argv, struct arg_hdr **table, struct arg_
 
             case '?':
                 /*
-                * getarg_long() found an unrecognised short option.
+                * getopt_long() found an unrecognised short option.
                 * if it was a short option its value is in optopt
                 * if it was a long option then optopt=0
                 */
@@ -334,10 +335,10 @@ void arg_parse_tagged(int argc, char **argv, struct arg_hdr **table, struct arg_
 
             case':':
                 /*
-                * getarg_long() found an option with its argument missing
+                * getopt_long() found an option with its argument missing.
                 */
-                printf(": option %s requires an argument\n",argv[optind-1]);
-                arg_register_error(endtable,endtable,ARG_EMISSARG,argv[optind-1]);
+                /*printf(": option %s requires an argument\n",argv[optind-1]); */
+                arg_register_error(endtable,endtable,ARG_EMISSARG,argv[optind-1]); 
                 break;
 
             default:
@@ -459,6 +460,7 @@ static
 void arg_parse_check(struct arg_hdr **table, struct arg_end *endtable)
     {
     int tabindex=0;
+    /* printf("arg_parse_check()\n"); */
     do
         {
         if (table[tabindex]->checkfn)
