@@ -27,6 +27,10 @@ echo $0 TESTS BEGIN
 ./test_int && fail
 ./test_int 1 2 3 4 && fail
 ./test_int 1 2 3 -d1 -d2 -d3 -d4 && fail
+./test_int 1 2 3 -d1 -d2 -d3 -d && fail
+./test_int 1 2 3 -d1 -d2 -d && fail
+./test_int 1 2 3 -d1 -d && fail
+./test_int 1 2 3 -d && fail
 ./test_int 1 2 3 --eps && fail
 ./test_int 1 2 3 --eps 3 --eqn 6 && fail
 ./test_int hello && fail
